package Acme::Version::Regress;

use 5.006;
use strict;
use warnings;

=head1 NAME

Acme::Version::Regress - Module for testing CPAN Pause indexing

=cut

our $VERSION = '3.00';

=head1 VERSION

Version 3.00

=cut

1; # End of Acme::Version::Regress
